@@ -7,13 +7,8 @@ from ape import plugins
 from ape.api.networks import LOCAL_NETWORK_NAME
 from ape_ethereum.ecosystem import NETWORKS
 
-from .provider import (
-    HardhatForkProvider,
-    HardhatNetworkConfig,
-    HardhatProvider,
-    HardhatProviderError,
-    HardhatSubprocessError,
-)
+from .exceptions import HardhatProviderError, HardhatSubprocessError
+from .provider import HardhatForkProvider, HardhatNetworkConfig, HardhatProvider
 
 
 @plugins.register(plugins.Config)
@@ -30,9 +25,19 @@ def providers():
 
     yield "fantom", LOCAL_NETWORK_NAME, HardhatProvider
     yield "fantom", "opera-fork", HardhatForkProvider
+    yield "fantom", "testnet-fork", HardhatForkProvider
 
     yield "arbitrum", LOCAL_NETWORK_NAME, HardhatProvider
     yield "arbitrum", "mainnet-fork", HardhatForkProvider
+    yield "arbitrum", "goerli-fork", HardhatForkProvider
+
+    yield "polygon", LOCAL_NETWORK_NAME, HardhatProvider
+    yield "polygon", "mainnet-fork", HardhatForkProvider
+    yield "polygon", "mumbai-fork", HardhatForkProvider
+
+    yield "optimism", LOCAL_NETWORK_NAME, HardhatProvider
+    yield "optimism", "mainnet-fork", HardhatForkProvider
+    yield "optimism", "goerli-fork", HardhatForkProvider
 
 
 __all__ = [
