@@ -33,11 +33,11 @@ from evm_trace import get_calltree_from_geth_trace
 from hexbytes import HexBytes
 from pydantic import BaseModel, Field
 from web3 import HTTPProvider, Web3
-from web3.eth import TxParams
 from web3.exceptions import ExtraDataLengthError
 from web3.gas_strategies.rpc import rpc_gas_price_strategy
 from web3.middleware import geth_poa_middleware
 from web3.middleware.validation import MAX_EXTRADATA_LENGTH
+from web3.types import TxParams
 
 from .exceptions import HardhatNotInstalledError, HardhatProviderError, HardhatSubprocessError
 
@@ -286,10 +286,8 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
 
         # Verify is actually a Hardhat provider,
         # or else skip it to possibly try another port.
-        # TODO: Once we are on web3.py 0.6.0b8 or later, can just use snake_case here.
-        client_version = getattr(self._web3, "client_version", getattr(self._web3, "clientVersion"))
-
-        if "hardhat" in client_version.lower():
+        client_version = self._web3.client_version.lower()
+        if "hardhat" in client_version:
             self._web3.eth.set_gas_price_strategy(rpc_gas_price_strategy)
         else:
             raise ProviderError(
@@ -417,50 +415,7 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
             receipt.raise_for_status()
 
         else:
-            try:
-                txn_hash = self.web3.eth.send_raw_transaction(txn.serialize_transaction())
-            except ValueError as err:
-                vm_err = self.get_virtual_machine_error(err, txn=txn)
-
-                if "nonce too low" in str(vm_err):
-                    # Add additional nonce information
-                    new_err_msg = f"Nonce '{txn.nonce}' is too low"
-                    raise VirtualMachineError(
-                        new_err_msg, base_err=vm_err.base_err, code=vm_err.code
-                    )
-
-                vm_err.txn = txn
-                raise vm_err from err
-
-            receipt = self.get_receipt(
-                txn_hash.hex(),
-                required_confirmations=(
-                    txn.required_confirmations
-                    if txn.required_confirmations is not None
-                    else self.network.required_confirmations
-                ),
-            )
-
-            if receipt.failed:
-                txn_dict = receipt.transaction.dict()
-                if isinstance(txn_dict.get("type"), int):
-                    txn_dict["type"] = HexBytes(txn_dict["type"]).hex()
-
-                txn_params = cast(TxParams, txn_dict)
-
-                # Replay txn to get revert reason
-                try:
-                    self.web3.eth.call(txn_params)
-                except Exception as err:
-                    vm_err = self.get_virtual_machine_error(err, txn=txn)
-                    vm_err.txn = txn
-                    raise vm_err from err
-
-            logger.info(
-                f"Confirmed {receipt.txn_hash} (total fees paid = {receipt.total_fees_paid})"
-            )
-            self.chain_manager.history.append(receipt)
-            return receipt
+            receipt = super().send_transaction(txn)
 
         return receipt
 
@@ -536,6 +491,11 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
         elif message == "Transaction ran out of gas":
             return OutOfGasError(txn=txn)
 
+        elif "reverted with an unrecognized custom error" in message and "(return data:" in message:
+            # Happens during custom Solidity exceptions.
+            message = message.split("(return data:")[-1].rstrip("/)").strip()
+            return ContractLogicError(revert_message=message, txn=txn)
+
         return VirtualMachineError(message)
 
 
